# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.1] - 2020-06-13
### Fixed
- there should always be an empty line before Additinal Information ...

## [0.1.0] - 2020-06-13
### Added
- initial version
